"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const aptos_client_1 = require("./aptos_client");
const faucet_client_1 = __importDefault(require("./faucet_client"));
const aptos_account_1 = __importDefault(require("./aptos_account"));
const nodeUrl = "https://fullnode.devnet.aptoslabs.com";
const faucetUrl = "https://faucet.devnet.aptoslabs.com";
test("full tutorial faucet flow", () => __awaiter(void 0, void 0, void 0, function* () {
    const client = new aptos_client_1.AptosClient(nodeUrl);
    const faucetClient = new faucet_client_1.default(nodeUrl, faucetUrl);
    const account1 = new aptos_account_1.default();
    yield faucetClient.fundAccount(account1.address(), 5000);
    let resources = yield client.getAccountResources(account1.address());
    let accountResource = resources.find((r) => r.type === "0x1::TestCoin::Balance");
    expect(accountResource.data.coin.value).toBe("5000");
    const account2 = new aptos_account_1.default();
    yield faucetClient.fundAccount(account2.address(), 0);
    resources = yield client.getAccountResources(account2.address());
    accountResource = resources.find((r) => r.type === "0x1::TestCoin::Balance");
    expect(accountResource.data.coin.value).toBe("0");
    const payload = {
        type: "script_function_payload",
        function: "0x1::TestCoin::transfer",
        type_arguments: [],
        arguments: [
            account2.address().hex(),
            "717",
        ]
    };
    const txnRequest = yield client.generateTransaction(account1.address(), payload);
    const signedTxn = yield client.signTransaction(account1, txnRequest);
    const transactionRes = yield client.submitTransaction(account1, signedTxn);
    yield client.waitForTransaction(transactionRes.hash);
    resources = yield client.getAccountResources(account2.address());
    accountResource = resources.find((r) => r.type === "0x1::TestCoin::Balance");
    expect(accountResource.data.coin.value).toBe("717");
    const res = yield client.getAccountTransactions(account1.address(), { start: 0 });
    const tx = res.find((e) => e.type === "user_transaction");
    expect(tx.sender).toBe(account1.address().hex());
}), 30 * 1000);
//# sourceMappingURL=faucet_client.test.js.map